@@ -1,5 +1,5 @@
 /* Determine the virtual memory area of a given address.
-   Copyright (C) 2006, 2008-2010, 2016-2018  Bruno Haible <bruno@clisp.org>
+   Copyright (C) 2006, 2008-2010, 2016-2018, 2021  Bruno Haible <bruno@clisp.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,6 +32,9 @@
    virtual memory ranges.  We try to work around this, but it may still be
    slow.  */
 
+/* Persuade Solaris OpenIndiana <unistd.h> to declare mincore().  */
+#define __EXTENSIONS__ 1
+
 #include "stackvma.h"
 #include <limits.h>
 #ifdef HAVE_UNISTD_H
@@ -50,7 +53,7 @@ typedef void* MINCORE_ADDR_T;
 
 /* The glibc declaration of mincore() uses 'unsigned char *', whereas the BSD
    declaration uses 'char *'.  */
-#if __GLIBC__ >= 2
+#if __GLIBC__ >= 2 || defined __ANDROID__
 typedef unsigned char pageinfo_t;
 #else
 typedef char pageinfo_t;
